@@ -30,36 +30,14 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ************************************************************************* 
 
-# -------------------------------------------
-# App::Dochazka::REST
-# -------------------------------------------
+# REST_Config.pm - Top-level configuration file providing default values for
+# various site configuration parameters. Any or all of these parameters can be
+# overrided in your site configuration file(s).
 #
-# REST_Config.pm - Top-level configuration file
-# providing default values for various site
-# configuration parameters. Any or all of these
-# parameters can be overrided in your site
-# configuration file(s).
-#
-# WARNING: THIS FILE MAY CONTAIN PASSWORDS
-# (restrictive permissions may be warranted)
-# -------------------------------------------
+# WARNING: THIS FILE MAY CONTAIN PASSWORDS (restrictive permissions may be
+#          warranted) 
 
 
-# DOCHAZKA_URI
-#    the bare URI where the server listens (no trailing '/') -- this
-#    information is used in the various "help" (or "default") resources. If
-#    this parameter is not set, the URI is obtained from the HTTP request
-#    itself.
-#set( 'DOCHAZKA_URI', 'http://dochazka.site' );
-
-# DOCHAZKA_HOST
-#    the hostname (vhost) where REST server will listen on a part
-set( 'DOCHAZKA_HOST', 'localhost' );
-
-# DOCHAZKA_PORT
-#    the port where the REST server will listen
-set( 'DOCHAZKA_PORT', 5000 );
-
 # DOCHAZKA_REST_LOG_FILE
 #     full path of log file to log to
 set( 'DOCHAZKA_REST_LOG_FILE', '/var/log/dochazka-rest.log' );
@@ -68,24 +46,11 @@ set( 'DOCHAZKA_REST_LOG_FILE', '/var/log/dochazka-rest.log' );
 #     should the logfile be deleted/wiped/unlinked/reset before each use
 set( 'DOCHAZKA_REST_LOG_FILE_RESET', 0 );
 
-# DOCHAZKA_DOCUMENTATION_URI
-#    used in the "help"/"default" resources
-set( 'DOCHAZKA_DOCUMENTATION_URI', 'https://metacpan.org/pod/App::Dochazka::REST' );
-
 # DOCHAZKA_REPORT_BUGS_TO
 #    this should be an ordinary string like "bugs@dochazka.com" or
 #    "http://bugs.dochazka.com"
 set( 'DOCHAZKA_REPORT_BUGS_TO', 'bug-App-Dochazka-REST@rt.cpan.org' );
 
-# DOCHAZKA_URI_MAX_LENGTH
-#    maximum length of a URI -- see Resource.pm->uri_too_long
-set( 'DOCHAZKA_URI_MAX_LENGTH', 1000 );
-
-# DOCHAZKA_APPNAME
-#    name of application (for logging) -- this can be set to any string, with
-#    the proviso that it should not contain ':' characters
-set( 'DOCHAZKA_APPNAME', 'App-Dochazka-REST' );
-
 # DOCHAZKA_DBNAME
 #    name of PostgreSQL database to use
 set( 'DOCHAZKA_DBNAME', 'dochazka-test' );
@@ -151,12 +116,6 @@ set( 'DOCHAZKA_ACTIVITY_DEFINITIONS', [
         { code => 'MEDICAL_LEAVE', long_desc => 'Statutory medical leave' },
     ] );   
 
-# DOCHAZKA_ADVANCE_INTERVALS_MAX_DAYS
-#     Some employees may try to enter attendance intervals days, weeks, 
-#     or even months in advance. This sets the maximum number of days
-#     in advance that Dochazka will accept an activity interval.
-set( 'DOCHAZKA_MAX_FUTURE_DAYS', 45 );
-
 # DOCHAZKA_BASIC_AUTH_REALM
 #     message displayed to user when she is asked to enter her credentials
 set( 'DOCHAZKA_BASIC_AUTH_REALM', 
@@ -211,10 +170,6 @@ set( 'DOCHAZKA_LDAP_POPULATE_MATRIX', {} );
 #     number of seconds after which a session will be considered stale
 set( 'DOCHAZKA_REST_SESSION_EXPIRATION_TIME', 3600 );
 
-# DOCHAZKA_REST_DEBUG_MODE
-#     whether or not debug- and trace-level messages are logged
-set( 'DOCHAZKA_REST_DEBUG_MODE', 0 );
-
 # DOCHAZKA_PROFILE_EDITABLE_FIELDS
 #     which employee fields can be updated by employees with privlevel 'inactive' and 'active'
 #     N.B. 1 administrators can edit all fields, and passerbies can't edit any
