@@ -396,9 +396,8 @@ sub vetted {
 
 =head2 fillup
 
-Takes a C<DBIx::Connector> object. In addition, it optionally takes an
-C<include_holidays> boolean flag, which defaults to 0. This method expects to
-be called on a fully vetted object (see C<vetted>, above).
+Optionally takes an C<include_holidays> boolean flag, which defaults to 0. This
+method expects to be called on a fully vetted object (see C<vetted>, above).
 
 This method attempts to INSERT records into the tempintvls table according to
 the tsrange and the employee's schedule.  Returns a status object.
@@ -411,18 +410,29 @@ intervals that will be created if the C<commit> method is called.
 
 sub fillup {
     my $self = shift;
+    my ( %ARGS ) = validate( @_, {
+        include_holidays => { type => SCALAR|UNDEF, default => 0 },
+    } );
     my $status;
+    my $include_holidays = $ARGS{'include_holidays'} ? 1 : 0;
+
+    die "ARG_NOT_VETTED" unless $self->vetted;
 
     my $rest_sched_hash_lower = _init_lower_sched_hash( $self->{sched_obj}->schedule );
 
-    my $holidays = holidays_in_daterange(
-        'begin' => $self->{lower_canon},
-        'end' => $self->{upper_canon},
-    );
+    my $holidays = $include_holidays 
+        ? undef
+        : holidays_in_daterange(
+            'begin' => $self->{lower_canon},
+            'end' => $self->{upper_canon},
+          );
 
+    # if $include_holidays is true, _is_holiday should be false over all
+    # values of $datum
     sub _is_holiday {
         my $datum = shift;
-        return exists( $holidays->{ $datum } );
+        return exists( $holidays->{ $datum } ) unless $include_holidays;
+        return 0;
     }
     
     # the insert operation needs to take place within a transaction
@@ -558,8 +568,8 @@ sub dump {
 
 =head2 commit
 
-Takes a PARAMHASH containing a C<DBIx::Connector> object and, optionally, a
-C<dry_run> boolean value that defaults to 0.
+Optionally takes a PARAMHASH containing, optionally, a C<dry_run> boolean value
+that defaults to 0.
 
 If C<dry_run> is true, merely SELECTs intervals from the tempintvls table
 corresponding to the tsrange (already vetted and stored in the object by
@@ -574,10 +584,10 @@ intervals table.
 sub commit {
     my $self = shift;
     my ( %ARGS ) = validate( @_, {
-        dry_run => { type => SCALAR, default => 0 },
+        dry_run => { type => SCALAR|UNDEF, default => 0 },
     } );
     my $status;
-    my $count;
+    my $dry_run = $ARGS{dry_run} ? 1 : 0;
     my $next = App::Dochazka::REST::Model::Tempintvls->spawn;
     die 'AGCKDSWQ#$L! newly spawned Tempintvls object has no TIID?' unless $next->tiid;
 
@@ -595,7 +605,6 @@ sub commit {
         ],
     );
     goto WRAPUP unless $status->ok;
-    $count = $status->payload;
 
     # get the rows we just wrote
     $status = select_set_of_single_scalar_rows(
@@ -603,11 +612,15 @@ sub commit {
         sql => $site->SQL_TEMPINTVLS_SELECT_COMMITTED,
         keys => [ $next->tiid ],
     );
-    if ( $ARGS{dry_run} ) {
+    my $fillup_intervals = $status->payload;
+    my $count = defined( $fillup_intervals )
+        ? @$fillup_intervals
+        : 0;
+    if ( $dry_run ) {
+        $status->{'count'} = $count;
         return $status;
     }
     goto WRAPUP unless $status->ok;
-    my $fillup_intervals = $status->payload;
     
     # write intervals to database
     $status = undef;
