@@ -34,7 +34,7 @@ package App::Dochazka::REST::Util;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use App::CELL qw( $log );
 use Authen::Passphrase::SaltedDigest;
